==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/BrushScaleDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { PropertyUpdatedEventArgsDescriptionMetadata } from "./PropertyUpdatedEventArgsDescriptionMetadata";
import { BrushScaleDescription } from "./BrushScaleDescription";
/**
 * @hidden
 */
export let BrushScaleDescriptionMetadata = /*@__PURE__*/ (() => {
    class BrushScaleDescriptionMetadata extends Base {
        static b(a) {
            if (BrushScaleDescriptionMetadata.a == null) {
                BrushScaleDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                BrushScaleDescriptionMetadata.c(BrushScaleDescriptionMetadata.a);
            }
            if (a.k(BrushScaleDescriptionMetadata.a)) {
                return;
            }
            a.ab(BrushScaleDescriptionMetadata.a);
            PropertyUpdatedEventArgsDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("Brushes", "BrushCollection:string");
            a.item("PropertyUpdatedRef", "EventRef::propertyUpdated");
        }
        static d(a) {
            BrushScaleDescriptionMetadata.b(a);
            a.ad("BrushScale", () => new BrushScaleDescription());
            a.ac("BrushScale", BrushScaleDescriptionMetadata.a);
        }
    }
    BrushScaleDescriptionMetadata.$t = markType(BrushScaleDescriptionMetadata, 'BrushScaleDescriptionMetadata');
    BrushScaleDescriptionMetadata.a = null;
    return BrushScaleDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/BrushScaleDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { PropertyUpdatedEventArgsDescriptionMetadata } from "./PropertyUpdatedEventArgsDescriptionMetadata";
import { BrushScaleDescription } from "./BrushScaleDescription";
/**
 * @hidden
 */
export let BrushScaleDescriptionMetadata = /*@__PURE__*/ (() => {
    class BrushScaleDescriptionMetadata extends Base {
        static b(a) {
            if (BrushScaleDescriptionMetadata.a == null) {
                BrushScaleDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                BrushScaleDescriptionMetadata.c(BrushScaleDescriptionMetadata.a);
            }
            if (a.k(BrushScaleDescriptionMetadata.a)) {
                return;
            }
            a.ac(BrushScaleDescriptionMetadata.a);
            PropertyUpdatedEventArgsDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("Brushes", "BrushCollection:string");
            a.item("PropertyUpdatedRef", "EventRef::propertyUpdated");
        }
        static d(a) {
            BrushScaleDescriptionMetadata.b(a);
            a.ae("BrushScale", () => new BrushScaleDescription());
            a.ad("BrushScale", BrushScaleDescriptionMetadata.a);
        }
    }
    BrushScaleDescriptionMetadata.$t = markType(BrushScaleDescriptionMetadata, 'BrushScaleDescriptionMetadata');
    BrushScaleDescriptionMetadata.a = null;
    return BrushScaleDescriptionMetadata;
})();
